expirationMonth property
Expiry month of the payer's card. For example: 08.
This parameter is required if the card number or an unencrypted token is being passed
Implementation
final String expirationMonth;
Expiry month of the payer's card. For example: 08.
This parameter is required if the card number or an unencrypted token is being passed
final String expirationMonth;