expirationYear property
Expiry year of the payer's card. For example: 19.
This parameter is required if the card number or an unencrypted token is being passed
Implementation
final String expirationYear;
Expiry year of the payer's card. For example: 19.
This parameter is required if the card number or an unencrypted token is being passed
final String expirationYear;